
# Slot: verbose


Verbosity mode, 0 or 1. Mode 0 is silent, and mode 1 displays messages when the callback takes an action.

URI: [https://w3id.org/neat/classifierCallback__verbose](https://w3id.org/neat/classifierCallback__verbose)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [ClassifierCallback](ClassifierCallback.md)
